@@ -257,25 +257,18 @@ class ReadOnlyDict(dict):
         raise NotImplementedError("Dictionary is read-only")
 
 
-def sort_dfs(data, sort_key="serial_index", children_key="children", reverse=False):
-    if data:
-        if isinstance(data, list):
-            # 使用lambda表达式获取sort_key的值，默认为0
-            # 使用或运算符（or）来处理None或其他假值的情况
-            data.sort(key=lambda item: item.get(sort_key, 0), reverse=reverse)
-
-            # 递归排序子元素
-            for element in data:
-                if isinstance(element, dict) and children_key in element:
-                    sort_dfs(element[children_key], sort_key=sort_key, children_key=children_key, reverse=reverse)
-        elif isinstance(data, dict):
-            if children_key in data:
-                # 排序字典中的子列表
-                data[children_key].sort(key=lambda item: item.get(sort_key, 0), reverse=reverse)
-
-                # 递归排序子元素
-                for sub_element in data[children_key]:
-                    sort_dfs(sub_element, sort_key=sort_key, children_key=children_key, reverse=reverse)
+def sort_dfs(_tree, sort_key="serial_index", children_key="children", reverse=False):
+    if _tree:
+        if isinstance(_tree, list):
+            _tree = sorted(_tree, key=lambda x: x.get(sort_key) or 0, reverse=reverse)
+            for _ in _tree:
+                sort_dfs(_, sort_key=sort_key, children_key=children_key, reverse=reverse)
+        if isinstance(_tree, dict):
+            if _tree.get(children_key):
+                _tree[children_key] = sorted(_tree.get(children_key), key=lambda x: x.get(sort_key) or 0,
+                                             reverse=reverse)
+                for _ in _tree.get(children_key):
+                    sort_dfs(_, sort_key=sort_key, children_key=children_key, reverse=reverse)
 
 
 def sort_tree(data, sort_key="serial_index", children_key="children", reverse=False):
