@@ -16,7 +16,7 @@ async def async_common_request(method, url, params=None, data=None, json=None,
     except ImportError as e:
         raise Exception(f"httpx is not exist,run:pip install httpx==0.24.1")
     if not connect_config or not isinstance(connect_config, dict):
-        connect_config = dict()
+        connect_config = {"timeout": None}
     with httpx.AsyncClient(**connect_config) as session:
         async with session.request(method.upper(), url=url, params=params, json=json, data=data,
                                    **kwargs) as resp:
@@ -38,7 +38,7 @@ def sync_common_request(method, url, params=None, data=None, json=None, result_t
     except ImportError as e:
         raise Exception(f"httpx is not exist,run:pip install httpx==0.24.1")
     if not connect_config or not isinstance(connect_config, dict):
-        connect_config = dict()
+        connect_config = {"timeout": None}
     with httpx.Client(**connect_config) as session:
         try:
             res = session.request(method.upper(), url=url, params=params, data=data, json=json, **kwargs)
